@@ -6,5 +6,5 @@ from .entity.dataset import Dataset
 from .entity.dataset_group import DatasetGroup
 from .entity.model import Model
 from .entity.model_group import ModelGroup
-from .entity.workflow import Workflow
-from .entity.job import Job
+from .entity.workflow import WorkFlow
+from .entity.task import Task
