@@ -166,6 +166,21 @@ def get_main_parser(resources, action=None, target=None):
             upload_parser.add_argument('-d', '--display-name', type=str, action='store', required=True, help='display name of entity')
             return upload_parser
 
+    if action == 'upload_partial' or action is None:
+        upload_partial_parser = subparsers.add_parser('upload_partial', help='upload partial resources')
+        upload_partial_support_resources = {name: res for name, res in list(resources.items()) if hasattr(res, 'do_upload_partial')}
+        resource_action = upload_partial_parser.add_argument('resource', action=DetectResourceAction,
+                                                     help='resource type, %s' % list(upload_partial_support_resources.keys()))
+        resource_action.resources = resources
+        resource_action.supported_resources = upload_partial_support_resources
+        if action is None:
+            upload_partial_parser.add_argument('args', nargs=argparse.REMAINDER)
+        else:
+            upload_partial_parser.add_argument('-f', '--file', type=str, action='store', required=True, help='file to upload')
+            upload_partial_parser.add_argument('--urn', type=str, action='store', required=True, help='target urn')
+            upload_partial_parser.add_argument('--path-prefix', type=str, action='store', required=False, help='target path prefix')
+            return upload_partial_parser
+
     if action == 'create' or action is None:
         create_parser = subparsers.add_parser('create', help='Create resources')
         create_support_resources = {name: res for name, res in list(resources.items()) if hasattr(res, 'do_create')}
@@ -283,7 +298,7 @@ def _main():
             ipython_main()
     elif main_args.action in (
             'get', 'delete', 'create', 'update', 'edit', 'describe',
-            'download', 'upload'):
+            'download', 'upload', 'upload_partial'):
         parser = get_resource_parser(resources, main_args.action, resources.get(main_args.resource))
         args = parser.parse_args([main_args.resource] + main_args.args)
         resource = resources.get(main_args.resource)
@@ -352,6 +367,10 @@ def _main():
             logger.debug('before upload %s', resource.name)
             resource.do_upload(context, args)
             logger.debug('after upload %s', resource.name)
+        elif main_args.action == 'upload_partial':
+            logger.debug('before upload partial %s', resource.name)
+            resource.do_upload_partial(context, args)
+            logger.debug('after upload patial %s', resource.name)
         elif main_args.action == 'create':
             ensure_true(not resource_id, 'create resource with id does not support')
             logger.debug('before create %s from %s', resource.name, getattr(args, 'from'))
