@@ -31,14 +31,14 @@ from .mixins.dataset import DatasetMixin
 from .mixins.dataset_group import DatasetGroupMixin
 from .mixins.model import ModelMixin
 from .mixins.model_group import ModelGroupMixin
-from .mixins.job import DataJobMixin
+from .mixins.task import TaskMixin
 from .mixins.workflow import WorkflowMixin
 
 logger = logging.getLogger(__name__)
 __all__ = ['Client']
 
 
-class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin, DataJobMixin, WorkflowMixin):
+class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin, TaskMixin, WorkflowMixin):
 
     def __init__(self, context: MetadataContext):
         self.context = context 
@@ -137,4 +137,9 @@ class Client(DatasetMixin, DatasetGroupMixin, ModelMixin, ModelGroupMixin, DataJ
         storage_client = self.context.storage_client
         ensure_true(storage_client, 'Storage Client required for context')
         for key in storage_client.list(storage_prefix, recursive=True):
-            storage_client.delete(key)
\ No newline at end of file
+            storage_client.delete(key)
+    
+    def list_artifact(self, storage_prefix):
+        storage_client = self.context.storage_client
+        ensure_true(storage_client, 'Storage Client required for context')
+        return storage_client.list(storage_prefix, recursive=True)
\ No newline at end of file
