@@ -77,7 +77,7 @@ class DatasetMixin:
             facts.append(('owners', [make_user_urn(self.context.user_email if owner == 'me' else owner), False, 'CONTAIN']))
         return self._get_entities_by_facts(Dataset.entity_type, facts, search=search, start=start, count=count)
     
-    def download_dataset(self, urn: str, dest: str, sub_paths: Optional[List[str]]):
+    def download_dataset(self, urn: str, dest: str, sub_paths: Optional[List[str]]=None):
         dataset = self.get_dataset(urn)
         storage_client = self.context.storage_client
         ensure_true(storage_client, 'Storage Client required for context')
