@@ -30,8 +30,4 @@ class Model(Entity):
     training_params: Optional[Dict[str, Any]] = field(repr=False, default=None)
 
     #: Metrics of the MLModel used in training
-    training_metrics: Optional[Dict[str, Any]] = field(repr=False, default=None)
-
-    downstream_jobs: Optional[List[str]] = field(repr=False, default=None)
-    training_jobs: Optional[List[str]] = field(repr=False, default=None)
-    deployments: Optional[List[str]] = field(repr=False, default=None)
\ No newline at end of file
+    training_metrics: Optional[Dict[str, Any]] = field(repr=False, default=None)
\ No newline at end of file
